pub struct Disconnected { /* private fields */ }Trait Implementations
Sourceimpl Clone for Disconnected
impl Clone for Disconnected
Sourcefn clone(&self) -> Disconnected
fn clone(&self) -> Disconnected
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Disconnected
impl Debug for Disconnected
Sourceimpl<D: ResourceDialect> Decode<Disconnected, D> for Disconnected
impl<D: ResourceDialect> Decode<Disconnected, D> for Disconnected
Sourceimpl Default for Disconnected
impl Default for Disconnected
Sourcefn default() -> Disconnected
fn default() -> Disconnected
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<Disconnected, D> for &Disconnected
impl<D: ResourceDialect> Encode<Disconnected, D> for &Disconnected
Sourceimpl PartialEq for Disconnected
impl PartialEq for Disconnected
Sourcefn eq(&self, other: &Disconnected) -> bool
fn eq(&self, other: &Disconnected) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for Disconnected
impl TypeMarker for Disconnected
Sourcetype Owned = Disconnected
type Owned = Disconnected
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Disconnected
impl ValueTypeMarker for Disconnected
Sourcetype Borrowed<'a> = &'a Disconnected
type Borrowed<'a> = &'a Disconnected
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for Disconnected
impl StructuralPartialEq for Disconnected