pub struct SourceGetSpecResponse {
pub spec: Spec,
}Fields
spec: SpecTrait Implementations
Sourceimpl Clone for SourceGetSpecResponse
impl Clone for SourceGetSpecResponse
Sourcefn clone(&self) -> SourceGetSpecResponse
fn clone(&self) -> SourceGetSpecResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceGetSpecResponse
impl Debug for SourceGetSpecResponse
Sourceimpl<D: ResourceDialect> Decode<SourceGetSpecResponse, D> for SourceGetSpecResponse
impl<D: ResourceDialect> Decode<SourceGetSpecResponse, D> for SourceGetSpecResponse
Sourceimpl<D: ResourceDialect> Encode<SourceGetSpecResponse, D> for &SourceGetSpecResponse
impl<D: ResourceDialect> Encode<SourceGetSpecResponse, D> for &SourceGetSpecResponse
Sourceimpl<D: ResourceDialect, T0: Encode<Spec, D>> Encode<SourceGetSpecResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<Spec, D>> Encode<SourceGetSpecResponse, D> for (T0,)
Sourceimpl PartialEq for SourceGetSpecResponse
impl PartialEq for SourceGetSpecResponse
Sourcefn eq(&self, other: &SourceGetSpecResponse) -> bool
fn eq(&self, other: &SourceGetSpecResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for SourceGetSpecResponse
impl TypeMarker for SourceGetSpecResponse
Sourcetype Owned = SourceGetSpecResponse
type Owned = SourceGetSpecResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SourceGetSpecResponse
impl ValueTypeMarker for SourceGetSpecResponse
Sourcetype Borrowed<'a> = &'a SourceGetSpecResponse
type Borrowed<'a> = &'a SourceGetSpecResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for SourceGetSpecResponse
impl StructuralPartialEq for SourceGetSpecResponse